==> sensiPhy_0.5.0.tar.gz: sensiPhy/R/document-data.R <==
#' Alien Mammals dataset: Example dataset for the package sensiPhy
#'
#' A comparative dataset containing traits for 94 alien mammal species 
#' (alien.data) and a multiphylo object with 101 phylogenies matching the 
#' data (alien.phy). Tip labels are the binomial species names and match 
#' with data rownames. Data was taken from (Gonzalez-Suarez et al. 2015) and phylogenies from
#' (Fritz et al 2009) and (Kuhn et al 2011). 
#' @usage data(alien)
#' @format A data frame with 94 rows and 7 variables:
#' \itemize{
#'   \item family: Taxonomic family
#'   \item adultMass: Mean adult body mass (g)
#'   \item gestaLen: Mean gestation length (days)
#'   \item homeRange: Mean home range (km)
#'   \item SE_mass: Standard deviation (intraspecific) for mean adult body mass (g)
#'   \item SE_gesta: Standard deviation (intraspecific) for mean gestation length (days)
#'   \item SE_range: Standard deviation (intraspecific) for mean home range (km)
#'   }
#' @format A multiphylo containing 101 trees for 94 mammal species.
#' @references Alien mammal data: Gonzalez-Suarez, Manuela, Sven Bacher, and Jonathan M. Jeschke. 
#' "Intraspecific trait variation is correlated with establishment success of alien mammals." 
#' The American Naturalist 185.6 (2015): 737-746  DOI: 10.1086/681105
#' 
#' Downloaded from: Gonzalez-Surez M, Bacher S, Jeschke J (2015) Data from: Intraspecific trait 
#' variation is correlated with establishment success of alien mammals.
#' Dryad Digital Repository. http://dx.doi.org/10.5061/dryad.sp963
#' 
#' Phylogeny: Kuhn, Tyler S., Arne O. Mooers, and Gavin H. Thomas. "A simple polytomy resolver for 
#' dated phylogenies." Methods in Ecology and Evolution 2.5 (2011): 427-436.
#' 
#' Fritz, Susanne A., Olaf RP Bininda-Emonds, and Andy Purvis. "Geographical variation in predictors 
#' of mammalian extinction risk: big is bad, but only in the tropics." Ecology letters 12.6 (2009): 538-549.
#' 
"alien"



#' Primates dataset: Example dataset for the package sensiPhy
#'
#' A comparative dataset containing traits for 95 Primates species 
#' (primates$data) and a multiphylo object with 101 phylogenies matching the 
#' data (primates$phy). Tip labels are the binomial species names and match 
#' with data rownames. Data was taken from (Jones et al. 2009) and phylogenies from
#' (Fritz et al 2009) and (Kuhn et al 2011). 
#' @usage data(primates)
#' @format A data frame with 95 rows and 3 variables:
#' \itemize{
#'   \item family: Taxonomic family
#'   \item adultMass: Mean adult body mass (g)
#'   \item sexMaturity: Age when individuals are first physically capable of reproducing (days)
#'   \item homeRange: Mean home range (km)
#'   }
#' @format A multiphylo containing 101 trees for 95 primate species.
#' @references 
#' 
#' Data downloaded from: http://esapubs.org/archive/ecol/E090/184/
#' 
#' Jones, K. E., Bielby, J., Cardillo, M., Fritz, S. A., O'Dell, J., Orme, C. D. L., Safi, K., Sechrest,
#'  W., Boakes, E. H., Carbone, C., Connolly, C., Cutts, M. J., Foster, J. K., Grenyer, R., Habib, M., Plaster, 
#'  C. A., Price, S. A., Rigby, E. A., Rist, J., Teacher, A., Bininda-Emonds, O. R. P., Gittleman, J. L., 
#'  Mace, G. M., Purvis, A. (2009), PanTHERIA: a species-level database of life history, ecology, 
#'  and geography of extant and recently extinct mammals. Ecology, 90: 2648. doi: 10.1890/08-1494.1
#' 
#' Phylogeny: Kuhn, Tyler S., Arne O. Mooers, and Gavin H. Thomas. "A simple polytomy resolver for 
#' dated phylogenies." Methods in Ecology and Evolution 2.5 (2011): 427-436.
#' 
#' Fritz, Susanne A., Olaf RP Bininda-Emonds, and Andy Purvis. "Geographical variation in predictors 
#' of mammalian extinction risk: big is bad, but only in the tropics." Ecology letters 12.6 (2009): 538-549.
#' 
"primates"

==> sensiPhy_0.7.0.tar.gz: sensiPhy/R/document-data.R <==
#' Alien Mammals dataset: Example dataset for the package sensiPhy
#'
#' A comparative dataset containing traits for 94 alien mammal species 
#' (alien.data) and a multiphylo object with 101 phylogenies matching the 
#' data (alien.phy). Tip labels are the binomial species names and match 
#' with data rownames. Data was taken from (Gonzalez-Suarez et al. 2015) and phylogenies from
#' (Fritz et al 2009) and (Kuhn et al 2011). 
#' @usage data(alien)
#' @format A data frame with 94 rows and 7 variables:
#' \itemize{
#'   \item family: Taxonomic family
#'   \item adultMass: Mean adult body mass (g)
#'   \item gestaLen: Mean gestation length (days)
#'   \item homeRange: Mean home range (km)
#'   \item SE_mass: Standard deviation (intraspecific) for mean adult body mass (g)
#'   \item SE_gesta: Standard deviation (intraspecific) for mean gestation length (days)
#'   \item SE_range: Standard deviation (intraspecific) for mean home range (km)
#'   }
#' @format A multiphylo containing 101 trees for 94 mammal species.
#' @references Alien mammal data: Gonzalez-Suarez, Manuela, Sven Bacher, and Jonathan M. Jeschke. 
#' "Intraspecific trait variation is correlated with establishment success of alien mammals." 
#' The American Naturalist 185.6 (2015): 737-746  DOI: 10.1086/681105
#' 
#' Downloaded from: Gonzalez-Surez M, Bacher S, Jeschke J (2015) Data from: Intraspecific trait 
#' variation is correlated with establishment success of alien mammals.
#' Dryad Digital Repository. http://dx.doi.org/10.5061/dryad.sp963
#' 
#' Phylogeny: Kuhn, Tyler S., Arne O. Mooers, and Gavin H. Thomas. "A simple polytomy resolver for 
#' dated phylogenies." Methods in Ecology and Evolution 2.5 (2011): 427-436.
#' 
#' Fritz, Susanne A., Olaf RP Bininda-Emonds, and Andy Purvis. "Geographical variation in predictors 
#' of mammalian extinction risk: big is bad, but only in the tropics." Ecology letters 12.6 (2009): 538-549.
#' 
"alien"

#' Alien Mammals dataset: Example dataset for the package sensiPhy
#'
#' A comparative dataset containing traits for 94 alien mammal species 
#' (alien.data) and a multiphylo object with 101 phylogenies matching the 
#' data (alien.phy). Tip labels are the binomial species names and match 
#' with data rownames. Data was taken from (Gonzalez-Suarez et al. 2015) and phylogenies from
#' (Fritz et al 2009) and (Kuhn et al 2011). 
#' @usage data(alien)
#' @format A data frame with 94 rows and 7 variables:
#' \itemize{
#'   \item family: Taxonomic family
#'   \item adultMass: Mean adult body mass (g)
#'   \item gestaLen: Mean gestation length (days)
#'   \item homeRange: Mean home range (km)
#'   \item SE_mass: Standard deviation (intraspecific) for mean adult body mass (g)
#'   \item SE_gesta: Standard deviation (intraspecific) for mean gestation length (days)
#'   \item SE_range: Standard deviation (intraspecific) for mean home range (km)
#'   }
#' @format A multiphylo containing 101 trees for 94 mammal species.
#' @references Alien mammal data: Gonzalez-Suarez, Manuela, Sven Bacher, and Jonathan M. Jeschke. 
#' "Intraspecific trait variation is correlated with establishment success of alien mammals." 
#' The American Naturalist 185.6 (2015): 737-746  DOI: 10.1086/681105
#' 
#' Downloaded from: Gonzalez-Surez M, Bacher S, Jeschke J (2015) Data from: Intraspecific trait 
#' variation is correlated with establishment success of alien mammals.
#' Dryad Digital Repository. http://dx.doi.org/10.5061/dryad.sp963
#' 
#' Phylogeny: Kuhn, Tyler S., Arne O. Mooers, and Gavin H. Thomas. "A simple polytomy resolver for 
#' dated phylogenies." Methods in Ecology and Evolution 2.5 (2011): 427-436.
#' 
#' Fritz, Susanne A., Olaf RP Bininda-Emonds, and Andy Purvis. "Geographical variation in predictors 
#' of mammalian extinction risk: big is bad, but only in the tropics." Ecology letters 12.6 (2009): 538-549.
#' 
"alien.data"

#' Alien Mammals dataset: Example dataset for the package sensiPhy
#'
#' A comparative dataset containing traits for 94 alien mammal species 
#' (alien.data) and a multiphylo object with 101 phylogenies matching the 
#' data (alien.phy). Tip labels are the binomial species names and match 
#' with data rownames. Data was taken from (Gonzalez-Suarez et al. 2015) and phylogenies from
#' (Fritz et al 2009) and (Kuhn et al 2011). 
#' @usage data(alien)
#' @format A data frame with 94 rows and 7 variables:
#' \itemize{
#'   \item family: Taxonomic family
#'   \item adultMass: Mean adult body mass (g)
#'   \item gestaLen: Mean gestation length (days)
#'   \item homeRange: Mean home range (km)
#'   \item SE_mass: Standard deviation (intraspecific) for mean adult body mass (g)
#'   \item SE_gesta: Standard deviation (intraspecific) for mean gestation length (days)
#'   \item SE_range: Standard deviation (intraspecific) for mean home range (km)
#'   }
#' @format A multiphylo containing 101 trees for 94 mammal species.
#' @references Alien mammal data: Gonzalez-Suarez, Manuela, Sven Bacher, and Jonathan M. Jeschke. 
#' "Intraspecific trait variation is correlated with establishment success of alien mammals." 
#' The American Naturalist 185.6 (2015): 737-746  DOI: 10.1086/681105
#' 
#' Downloaded from: Gonzalez-Surez M, Bacher S, Jeschke J (2015) Data from: Intraspecific trait 
#' variation is correlated with establishment success of alien mammals.
#' Dryad Digital Repository. http://dx.doi.org/10.5061/dryad.sp963
#' 
#' Phylogeny: Kuhn, Tyler S., Arne O. Mooers, and Gavin H. Thomas. "A simple polytomy resolver for 
#' dated phylogenies." Methods in Ecology and Evolution 2.5 (2011): 427-436.
#' 
#' Fritz, Susanne A., Olaf RP Bininda-Emonds, and Andy Purvis. "Geographical variation in predictors 
#' of mammalian extinction risk: big is bad, but only in the tropics." Ecology letters 12.6 (2009): 538-549.
#' 
"alien.phy"


#' Primates dataset: Example dataset for the package sensiPhy
#'
#' A comparative dataset containing traits for 95 Primates species 
#' (primates.data) and a multiphylo object with 101 phylogenies matching the 
#' data (primates.phy). Tip labels are the binomial species names and match 
#' with data rownames. Data was taken from (Jones et al. 2009) and phylogenies from
#' (Fritz et al 2009) and (Kuhn et al 2011). 
#' @usage data(primates)
#' @format A data frame with 95 rows and 3 variables:
#' \itemize{
#'   \item family: Taxonomic family
#'   \item adultMass: Mean adult body mass (g)
#'   \item sexMaturity: Age when individuals are first physically capable of reproducing (days)
#'   \item homeRange: Mean home range (km)
#'   }
#' @format A multiphylo containing 101 trees for 95 primate species.
#' @references 
#' 
#' Data downloaded from: http://esapubs.org/archive/ecol/E090/184/
#' 
#' Jones, K. E., Bielby, J., Cardillo, M., Fritz, S. A., O'Dell, J., Orme, C. D. L., Safi, K., Sechrest,
#'  W., Boakes, E. H., Carbone, C., Connolly, C., Cutts, M. J., Foster, J. K., Grenyer, R., Habib, M., Plaster, 
#'  C. A., Price, S. A., Rigby, E. A., Rist, J., Teacher, A., Bininda-Emonds, O. R. P., Gittleman, J. L., 
#'  Mace, G. M., Purvis, A. (2009), PanTHERIA: a species-level database of life history, ecology, 
#'  and geography of extant and recently extinct mammals. Ecology, 90: 2648. doi: 10.1890/08-1494.1
#' 
#' Phylogeny: Kuhn, Tyler S., Arne O. Mooers, and Gavin H. Thomas. "A simple polytomy resolver for 
#' dated phylogenies." Methods in Ecology and Evolution 2.5 (2011): 427-436.
#' 
#' Fritz, Susanne A., Olaf RP Bininda-Emonds, and Andy Purvis. "Geographical variation in predictors 
#' of mammalian extinction risk: big is bad, but only in the tropics." Ecology letters 12.6 (2009): 538-549.
#' 
"primates"

#' Primates dataset: Example dataset for the package sensiPhy
#'
#' A comparative dataset containing traits for 95 Primates species 
#' (primates.data) and a multiphylo object with 101 phylogenies matching the 
#' data (primates.phy). Tip labels are the binomial species names and match 
#' with data rownames. Data was taken from (Jones et al. 2009) and phylogenies from
#' (Fritz et al 2009) and (Kuhn et al 2011). 
#' @usage data(primates)
#' @format A data frame with 95 rows and 3 variables:
#' \itemize{
#'   \item family: Taxonomic family
#'   \item adultMass: Mean adult body mass (g)
#'   \item sexMaturity: Age when individuals are first physically capable of reproducing (days)
#'   \item homeRange: Mean home range (km)
#'   }
#' @format A multiphylo containing 101 trees for 95 primate species.
#' @references 
#' 
#' Data downloaded from: http://esapubs.org/archive/ecol/E090/184/
#' 
#' Jones, K. E., Bielby, J., Cardillo, M., Fritz, S. A., O'Dell, J., Orme, C. D. L., Safi, K., Sechrest,
#'  W., Boakes, E. H., Carbone, C., Connolly, C., Cutts, M. J., Foster, J. K., Grenyer, R., Habib, M., Plaster, 
#'  C. A., Price, S. A., Rigby, E. A., Rist, J., Teacher, A., Bininda-Emonds, O. R. P., Gittleman, J. L., 
#'  Mace, G. M., Purvis, A. (2009), PanTHERIA: a species-level database of life history, ecology, 
#'  and geography of extant and recently extinct mammals. Ecology, 90: 2648. doi: 10.1890/08-1494.1
#' 
#' Phylogeny: Kuhn, Tyler S., Arne O. Mooers, and Gavin H. Thomas. "A simple polytomy resolver for 
#' dated phylogenies." Methods in Ecology and Evolution 2.5 (2011): 427-436.
#' 
#' Fritz, Susanne A., Olaf RP Bininda-Emonds, and Andy Purvis. "Geographical variation in predictors 
#' of mammalian extinction risk: big is bad, but only in the tropics." Ecology letters 12.6 (2009): 538-549.
#' 
"primates.data"

#' Primates dataset: Example dataset for the package sensiPhy
#'
#' A comparative dataset containing traits for 95 Primates species 
#' (primates.data) and a multiphylo object with 101 phylogenies matching the 
#' data (primates.phy). Tip labels are the binomial species names and match 
#' with data rownames. Data was taken from (Jones et al. 2009) and phylogenies from
#' (Fritz et al 2009) and (Kuhn et al 2011). 
#' @usage data(primates)
#' @format A data frame with 95 rows and 3 variables:
#' \itemize{
#'   \item family: Taxonomic family
#'   \item adultMass: Mean adult body mass (g)
#'   \item sexMaturity: Age when individuals are first physically capable of reproducing (days)
#'   \item homeRange: Mean home range (km)
#'   }
#' @format A multiphylo containing 101 trees for 95 primate species.
#' @references 
#' 
#' Data downloaded from: http://esapubs.org/archive/ecol/E090/184/
#' 
#' Jones, K. E., Bielby, J., Cardillo, M., Fritz, S. A., O'Dell, J., Orme, C. D. L., Safi, K., Sechrest,
#'  W., Boakes, E. H., Carbone, C., Connolly, C., Cutts, M. J., Foster, J. K., Grenyer, R., Habib, M., Plaster, 
#'  C. A., Price, S. A., Rigby, E. A., Rist, J., Teacher, A., Bininda-Emonds, O. R. P., Gittleman, J. L., 
#'  Mace, G. M., Purvis, A. (2009), PanTHERIA: a species-level database of life history, ecology, 
#'  and geography of extant and recently extinct mammals. Ecology, 90: 2648. doi: 10.1890/08-1494.1
#' 
#' Phylogeny: Kuhn, Tyler S., Arne O. Mooers, and Gavin H. Thomas. "A simple polytomy resolver for 
#' dated phylogenies." Methods in Ecology and Evolution 2.5 (2011): 427-436.
#' 
#' Fritz, Susanne A., Olaf RP Bininda-Emonds, and Andy Purvis. "Geographical variation in predictors 
#' of mammalian extinction risk: big is bad, but only in the tropics." Ecology letters 12.6 (2009): 538-549.
#' 
"primates.phy"
